<?php

/**
 * WebAdmin Language File
* English(en-US)
*
* Please Note: These language files will be overwritten during software updates.
*
* @author     LiteSpeed Technoglogies
* @copyright  Copyright (c) LiteSpeed 2014-2020
* @link       https://www.litespeedtech.com/
*/

global $_gmsg;

$_gmsg['menu_cloudimage'] = 'Cloud Images';
$_gmsg['menu_cluster'] = 'Clusters';
$_gmsg['menu_community'] = 'Community';
$_gmsg['menu_compilephp'] = 'Compile PHP';
$_gmsg['menu_dashboard'] = 'Dashboard';
$_gmsg['menu_devgroup'] = 'Developer Mailing List';
$_gmsg['menu_docs'] = 'Documentation';
$_gmsg['menu_forum'] = 'Forum';
$_gmsg['menu_general'] = 'General';
$_gmsg['menu_guides'] = 'Guides';
$_gmsg['menu_help'] = 'Help';
$_gmsg['menu_logviewer'] = 'Server Log Viewer';
$_gmsg['menu_releaselog'] = 'Release Log';
$_gmsg['menu_restart'] = 'Graceful Restart';
$_gmsg['menu_rtstats'] = 'Real-Time Stats';
$_gmsg['menu_serv'] = 'Server Configuration';
$_gmsg['menu_sl'] = 'Listeners';
$_gmsg['menu_sl_'] = 'Listener';
$_gmsg['menu_slack'] = 'Slack';
$_gmsg['menu_toggledebug'] = 'Toggle Debug';
$_gmsg['menu_tools'] = 'Tools';
$_gmsg['menu_tp'] = 'VHost Templates';
$_gmsg['menu_tp_'] = 'VHost Template';
$_gmsg['menu_versionmgr'] = 'Version Manager';
$_gmsg['menu_vh'] = 'Virtual Hosts';
$_gmsg['menu_vh_'] = 'Virtual Host';
$_gmsg['menu_webadmin'] = 'WebAdmin Settings';


$_gmsg['tab_addons'] = 'Add-ons';
$_gmsg['tab_base'] = 'Basic';
$_gmsg['tab_cache'] = 'Cache';
$_gmsg['tab_ctx'] = 'Context';
$_gmsg['tab_ext'] = 'External App';
$_gmsg['tab_g'] = 'General';
$_gmsg['tab_log'] = 'Log';
$_gmsg['tab_mod'] = 'Modules';
$_gmsg['tab_rails'] = 'App Server';
$_gmsg['tab_requestfilter'] = 'Request Filter';
$_gmsg['tab_rewrite'] = 'Rewrite';
$_gmsg['tab_sec'] = 'Security';
$_gmsg['tab_sh'] = 'Script Handler';
$_gmsg['tab_ssl'] = 'SSL';
$_gmsg['tab_top'] = 'Summary';
$_gmsg['tab_tp'] = 'Template';
$_gmsg['tab_tuning'] = 'Tuning';
$_gmsg['tab_user'] = 'Users';
$_gmsg['tab_wsp'] = 'Web Socket Proxy';


$_gmsg['btn_add'] = 'Add';
$_gmsg['btn_back'] = 'Back';
$_gmsg['btn_cancel'] = 'Cancel';
$_gmsg['btn_delete'] = 'Delete';
$_gmsg['btn_edit'] = 'Edit';
$_gmsg['btn_go'] = 'Go';
$_gmsg['btn_instantiate'] = 'Instantiate';
$_gmsg['btn_next'] = 'Next';
$_gmsg['btn_prev'] = 'Prev';
$_gmsg['btn_refresh'] = 'Refresh';
$_gmsg['btn_save'] = 'Save';
$_gmsg['btn_signin'] = 'Login';
$_gmsg['btn_view'] = 'View';
$_gmsg['btn_yes'] = 'Yes';


$_gmsg['note_collapsemenu'] = 'Collapse Menu';
$_gmsg['note_configmodified'] = 'Configuration has been modified. To apply changes, please perform a graceful restart.';
$_gmsg['note_confirm_delete'] = 'Are you sure you want to delete this entry? This will be permanently removed from the configuration file.';
$_gmsg['note_confirm_instantiate'] = 'Are you sure you want to instantiate this virtual host? This will create a dedicated configuration file for this virtual host.';
$_gmsg['note_confirm_logout'] = 'Logout';
$_gmsg['note_copyrightreserved'] = 'All Rights Reserved.';
$_gmsg['note_curbranch'] = 'current branch';
$_gmsg['note_curver'] = 'Current Version';
$_gmsg['note_dataretrievedat'] = 'Data retrieved at';
$_gmsg['note_entfeature'] = 'This feature is available in Enterprise Edition';
$_gmsg['note_example'] = 'Example';
$_gmsg['note_fullscreen'] = 'Full Screen';
$_gmsg['note_home'] = 'Home';
$_gmsg['note_inputerr'] = 'Input error detected. Please resolve the error(s).';
$_gmsg['note_loadavg'] = 'System Load Avg';
$_gmsg['note_logout'] = 'You can improve your security further after logging out by closing this opened browser';
$_gmsg['note_multicpufeature'] = 'This feature is available for Multiple-CPU license';
$_gmsg['note_newver'] = 'New Release';
$_gmsg['note_number'] = 'Number';
$_gmsg['note_numvalidrange'] = 'Number valid range';
$_gmsg['note_readonly_mode'] = 'Include file detected in configuration file. Entering Read-only mode.';
$_gmsg['note_select_option'] = 'Please select';
$_gmsg['note_serv_level'] = 'Server Level';
$_gmsg['note_signout'] = 'Sign Out';
$_gmsg['note_syntax'] = 'Syntax';
$_gmsg['note_tips'] = 'Tip(s)';
$_gmsg['note_vh_level'] = 'VHost Level';


$_gmsg['err_faildetectdlmethod'] = 'Unable to detect download method (install curl, fetch, or wget)';
$_gmsg['err_failreadfile'] = 'Failed to read file';
$_gmsg['err_illegalcharfound'] = 'Illegal characters found in value.';
$_gmsg['err_invalidpath'] = 'Invalid path';
$_gmsg['err_invalidvalat'] = 'Invalid value at';
$_gmsg['err_loggedoff'] = 'You have logged off.';
$_gmsg['err_login'] = 'Invalid credentials.';
$_gmsg['err_menuanchornotexist'] = 'Error - menu anchor does not exist';
$_gmsg['err_page_404'] = 'Error 404! Page not found.';
$_gmsg['err_parentdirnotexist'] = 'Parent directory does not exist';
$_gmsg['err_requireabspath'] = 'Require absolute path';
$_gmsg['err_sessiontimeout'] = 'Your session has timed out.';
$_gmsg['err_valcannotempty'] = 'Value cannot be empty';


$_gmsg['l_accessallow'] = 'Allowed List';
$_gmsg['l_accessallowed'] = 'Access Allowed';
$_gmsg['l_accesscontrol'] = 'Access Control';
$_gmsg['l_accessdenied'] = 'Access Denied';
$_gmsg['l_accessdeny'] = 'Denied List';
$_gmsg['l_accessdenydir'] = 'Access Denied Directories';
$_gmsg['l_accessfilename'] = 'Access File Name';
$_gmsg['l_accesslog'] = 'Access Log';
$_gmsg['l_action'] = 'Actions';
$_gmsg['l_adddefaultcharset'] = 'Add Default Charset';
$_gmsg['l_address'] = 'Address';
$_gmsg['l_addresssettings'] = 'Address Settings';
$_gmsg['l_adminemails'] = 'Administrator Email';
$_gmsg['l_adminlistenersettings'] = 'Admin Listener Address Settings';
$_gmsg['l_adminuser'] = 'WebAdmin Console User';
$_gmsg['l_adminusers'] = 'WebAdmin Console Users';
$_gmsg['l_aioblocksize'] = 'AIO Block Size';
$_gmsg['l_allowbrowse'] = 'Accessible';
$_gmsg['l_allowdirectaccess'] = 'Allow Direct Access';
$_gmsg['l_allowedRobotHits'] = 'Allowed Robot Hits';
$_gmsg['l_allowedhosts'] = 'Allowed Domains';
$_gmsg['l_allowoverride'] = 'Allow Override';
$_gmsg['l_allowquic'] = 'Allow QUIC';
$_gmsg['l_allowsetuid'] = 'Allow Set UID';
$_gmsg['l_allowsymbollink'] = 'Follow Symbolic Link';
$_gmsg['l_apachebinpath'] = 'Apache Binary Path';
$_gmsg['l_apacheconf'] = 'Apache Style configurations';
$_gmsg['l_apacheconffile'] = 'Apache Configuration File';
$_gmsg['l_apacheenablefp'] = 'Enable FrontPage Extension';
$_gmsg['l_apacheenvvars'] = 'Apache Environment';
$_gmsg['l_apachehandledcontent'] = 'Apache Handled Content';
$_gmsg['l_apacheignoredmodules'] = 'Ignore Apache Modules';
$_gmsg['l_apacheipoffset'] = 'Apache IP Offset';
$_gmsg['l_apacheportoffset'] = 'Apache Port Offset';
$_gmsg['l_apachestyleconf'] = 'Apache Style Configurations';
$_gmsg['l_apptype'] = 'Application Type';
$_gmsg['l_authname'] = 'Authentication Name';
$_gmsg['l_authorizer'] = 'Authorizer';
$_gmsg['l_authrealm'] = 'Authentication Realm';
$_gmsg['l_autoLoadRewriteHtaccess'] = 'Auto Load from .htaccess';
$_gmsg['l_autofix503'] = 'Auto Fix 503 Error';
$_gmsg['l_autoindex'] = 'Auto Index';
$_gmsg['l_autoindexuri'] = 'Auto Index URI';
$_gmsg['l_autoreloadapacheconf'] = 'Auto Reload On Changes';
$_gmsg['l_autostart'] = 'Start By Server';
$_gmsg['l_autoupdatedownload'] = 'Download Updates';
$_gmsg['l_autoupdateinterval'] = 'Check For Update';
$_gmsg['l_awstatesintegration'] = 'AWStats Integration';
$_gmsg['l_awstatsuri'] = 'AWStats URI';
$_gmsg['l_backlog'] = 'Back Log';
$_gmsg['l_banperiod'] = 'Banned Period (sec)';
$_gmsg['l_base'] = 'Base';
$_gmsg['l_base2'] = 'Base2';
$_gmsg['l_binding'] = 'Binding';
$_gmsg['l_binpath'] = 'Binary Path';
$_gmsg['l_blockbadreq'] = 'Block Bad Request';
$_gmsg['l_botWhiteList'] = 'Bot White List';
$_gmsg['l_brcompress'] = 'Brotli Compression';
$_gmsg['l_brcompresslevel'] = 'Brotli Compression Level (Dynamic Content)';
$_gmsg['l_brstaticcompresslevel'] = 'Brotli Compression Level (Static File)';
$_gmsg['l_bubblewrap'] = 'Bubblewrap Container';
$_gmsg['l_bubblewrapcmd'] = 'Bubblewrap Command';
$_gmsg['l_byteslog'] = 'Bytes log';
$_gmsg['l_cacertfile'] = 'CA Certificate File';
$_gmsg['l_cacertpath'] = 'CA Certificate Path';
$_gmsg['l_cacheexpiretime'] = 'Cache Expire Time (seconds)';
$_gmsg['l_cachepolicy'] = 'Cache Policy';
$_gmsg['l_cacheqs'] = 'Cache Request with Query String';
$_gmsg['l_cachereqcookie'] = 'Cache Request with Cookie';
$_gmsg['l_cacherespcookie'] = 'Cache Response with Cookie';
$_gmsg['l_cachestaleage'] = 'Cache Stale Age (seconds)';
$_gmsg['l_cachestoragesettings'] = 'Cache Storage Settings';
$_gmsg['l_certchain'] = 'Chained Certificate';
$_gmsg['l_certfile'] = 'Certificate File';
$_gmsg['l_cgidsock'] = 'CGI Daemon Socket';
$_gmsg['l_cgipriority'] = 'CGI Priority';
$_gmsg['l_cgisettings'] = 'CGI Settings';
$_gmsg['l_cgroups'] = 'cgroups';
$_gmsg['l_checksymbollink'] = 'Check Symbolic Link';
$_gmsg['l_chrootpath'] = 'chroot Path';
$_gmsg['l_ciphers'] = 'Ciphers';
$_gmsg['l_clientverify'] = 'Client Verification';
$_gmsg['l_command'] = 'Command';
$_gmsg['l_compressarchive'] = 'Compress Archive';
$_gmsg['l_compressibletypes'] = 'Compressible Types';
$_gmsg['l_concurrentReqLimit'] = 'Concurrent Request Limit';
$_gmsg['l_configfile'] = 'Config File';
$_gmsg['l_congestionctrl'] = 'Congestion Control';
$_gmsg['l_connection'] = 'Connection';
$_gmsg['l_conntimeout'] = 'Connection Timeout (secs)';
$_gmsg['l_contextlist'] = 'Context List';
$_gmsg['l_cpuaffinity'] = 'CPU Affinity';
$_gmsg['l_cpuhardlimit'] = 'CPU Hard Limit (sec)';
$_gmsg['l_cpusoftlimit'] = 'CPU Soft Limit (sec)';
$_gmsg['l_crlfile'] = 'Client Revocation File';
$_gmsg['l_crlpath'] = 'Client Revocation Path';
$_gmsg['l_ctxas'] = 'App Server Context Definition';
$_gmsg['l_ctxb'] = 'Load Balancer Context Definition';
$_gmsg['l_ctxc'] = 'CGI Context Definition';
$_gmsg['l_ctxf'] = 'FCGI Context Definition';
$_gmsg['l_ctxg'] = 'Static Context Definition';
$_gmsg['l_ctxj'] = 'Java WebApp Context Definition';
$_gmsg['l_ctxl'] = 'LiteSpeed SAPI Context Definition';
$_gmsg['l_ctxmd'] = 'Module Handler Context Definition';
$_gmsg['l_ctxp'] = 'Proxy Context Definition';
$_gmsg['l_ctxr'] = 'Redirect Context Definition';
$_gmsg['l_ctxs'] = 'Servlet Context Definition';
$_gmsg['l_custerrpages'] = 'Customized Error Pages';
$_gmsg['l_dbname'] = 'DB Name';
$_gmsg['l_debuglevel'] = 'Debug Level';
$_gmsg['l_defaultaction'] = 'Default Action';
$_gmsg['l_defaultcharsetcustomized'] = 'Customized Default Charset';
$_gmsg['l_defaultmimetype'] = 'Default MIME Type';
$_gmsg['l_defaultvhroot'] = 'Default Virtual Host Root';
$_gmsg['l_desturi'] = 'Destination URI';
$_gmsg['l_dhparam'] = 'DH Parameter';
$_gmsg['l_disableinitlogrotation'] = 'Disable Initial Log Rotation';
$_gmsg['l_disablesechtaccess'] = 'Disable .htaccess Override';
$_gmsg['l_docroot'] = 'Document Root';
$_gmsg['l_domain'] = 'Domain Name';
$_gmsg['l_domains'] = 'Domains';
$_gmsg['l_dynreqpersec'] = 'Dynamic Requests/second';
$_gmsg['l_enablecache'] = 'Enable Cache';
$_gmsg['l_enablecensorship'] = 'Enable Request Filtering';
$_gmsg['l_enablechroot'] = 'Enable chroot';
$_gmsg['l_enablecompress'] = 'Enable Compression';
$_gmsg['l_enablecoredump'] = 'Enable Core Dump';
$_gmsg['l_enabled'] = 'Enabled';
$_gmsg['l_enabledhe'] = 'Enable DH Key Exchange';
$_gmsg['l_enabledyngzipcompress'] = 'Enable GZIP Dynamic Compression';
$_gmsg['l_enableecdhe'] = 'Enable ECDH Key Exchange';
$_gmsg['l_enableexpires'] = 'Enable Expires';
$_gmsg['l_enablegzip'] = 'Enable GZIP Compression';
$_gmsg['l_enableh2c'] = 'Enable HTTP/2 Over Cleartext TCP';
$_gmsg['l_enablehooks'] = 'Enable Module';
$_gmsg['l_enablehotlinkctrl'] = 'Enable Hotlink Protection';
$_gmsg['l_enableipgeo'] = 'Enable GeoLocation Lookup';
$_gmsg['l_enablelve'] = 'Cloud Linux';
$_gmsg['l_enableprivatecache'] = 'Enable Private Cache';
$_gmsg['l_enablequic'] = 'Enable QUIC';
$_gmsg['l_enablerailshosting'] = 'Enable Shared Hosting';
$_gmsg['l_enablerewrite'] = 'Enable Rewrite';
$_gmsg['l_enablescript'] = 'Enable Scripts/ExtApps';
$_gmsg['l_enablespdy'] = 'Enable SPDY/HTTP2/HTTP3';
$_gmsg['l_enablestapling'] = 'Enable OCSP Stapling';
$_gmsg['l_enablestderrlog'] = 'Enable stderr Log';
$_gmsg['l_env'] = 'Environment';
$_gmsg['l_envvariable'] = 'Environment Variables';
$_gmsg['l_errcode'] = 'Error Code';
$_gmsg['l_expires'] = 'Expires Settings';
$_gmsg['l_expiresByType'] = 'Expires By Type';
$_gmsg['l_expiresdefault'] = 'Expires Default';
$_gmsg['l_extappabort'] = 'External Application Abort';
$_gmsg['l_extappchrootmode'] = 'External App Chroot Mode';
$_gmsg['l_extappchrootpath'] = 'External App Chroot Path';
$_gmsg['l_extapps'] = 'External Applications';
$_gmsg['l_extappsec'] = 'External App Security';
$_gmsg['l_externalredirect'] = 'External Redirect';
$_gmsg['l_extfcgiauth'] = 'FastCGI Authorizer';
$_gmsg['l_extlb'] = 'Load Balancer';
$_gmsg['l_extlogger'] = 'Piped Logger';
$_gmsg['l_extlsapi'] = 'LiteSpeed SAPI App';
$_gmsg['l_extproxy'] = 'Web Server';
$_gmsg['l_extraHeaders'] = 'Header Operations';
$_gmsg['l_extservlet'] = 'Servlet Engine';
$_gmsg['l_fcgiapp'] = 'FastCGI App';
$_gmsg['l_fileaccess'] = 'File Access';
$_gmsg['l_fileaccesscontrol'] = 'File Access Control';
$_gmsg['l_fileetag'] = 'File ETag';
$_gmsg['l_filename'] = 'File Name';
$_gmsg['l_followsymbollink'] = 'Follow Symbolic Link';
$_gmsg['l_forcegid'] = 'Force GID';
$_gmsg['l_forcemimetype'] = 'Force MIME Type';
$_gmsg['l_forcestrictownership'] = 'Force Strict Ownership';
$_gmsg['l_generalsettings'] = 'General Settings';
$_gmsg['l_geoipdb'] = 'MaxMind GeoIP DB';
$_gmsg['l_geoipdbfile'] = 'DB File Path';
$_gmsg['l_gracefulrestarttimeout'] = 'Graceful Restart Timeout (secs)';
$_gmsg['l_graceperiod'] = 'Grace Period (sec)';
$_gmsg['l_groupdbattrgroupmember'] = 'Group Member Attribute';
$_gmsg['l_groupdbcachetimeout'] = 'Group DB Cache Timeout (secs)';
$_gmsg['l_groupdbentries'] = 'Group DB Entries';
$_gmsg['l_groupdbentry'] = 'Group DB Entry';
$_gmsg['l_groupdblocation'] = 'Group DB Location';
$_gmsg['l_groupdbmaxcachesize'] = 'Group DB Max Cache Size';
$_gmsg['l_groupname'] = 'Group Name';
$_gmsg['l_groups'] = 'Groups';
$_gmsg['l_gzipautoupdatestatic'] = 'Auto Update Static File';
$_gmsg['l_gzipbr'] = 'GZIP/Brotli Compression';
$_gmsg['l_gzipcachedir'] = 'Static Cache Directory';
$_gmsg['l_gzipcompresslevel'] = 'GZIP Compression Level (Dynamic Content)';
$_gmsg['l_gzipmaxfilesize'] = 'Max Static File Size (bytes)';
$_gmsg['l_gzipminfilesize'] = 'Min Static File Size (bytes)';
$_gmsg['l_gzipstaticcompresslevel'] = 'GZIP Compression Level (Static File)';
$_gmsg['l_handlername'] = 'Handler Name';
$_gmsg['l_handlertype'] = 'Handler Type';
$_gmsg['l_hardlimit'] = 'Connection Hard Limit';
$_gmsg['l_hidesiginerrorpage'] = 'Hide Error Page Signature';
$_gmsg['l_hook'] = 'Hook';
$_gmsg['l_hotlinkprotection'] = 'Hotlink Protection';
$_gmsg['l_ignorereqcachectrl'] = 'Ignore Request Cache-Control';
$_gmsg['l_ignorerespcachectrl'] = 'Ignore Response Cache-Control';
$_gmsg['l_inbandwidth'] = 'Inbound Bandwidth (bytes/sec)';
$_gmsg['l_indexfiles'] = 'Index Files';
$_gmsg['l_inittimeout'] = 'Initial Request Timeout (secs)';
$_gmsg['l_inmembufsize'] = 'Memory I/O Buffer';
$_gmsg['l_instances'] = 'Instances';
$_gmsg['l_internal'] = 'Is Internal';
$_gmsg['l_ip'] = 'IP Address';
$_gmsg['l_ip2locDB'] = 'IP2Location DB';
$_gmsg['l_ip2locDBCache'] = 'DB Cache Type';
$_gmsg['l_ip2locDBFile'] = 'IP2Location DB File Path';
$_gmsg['l_keepalivetimeout'] = 'Keep-Alive Timeout (secs)';
$_gmsg['l_keepdays'] = 'Keep Days';
$_gmsg['l_keyfile'] = 'Private Key File';
$_gmsg['l_ldapbinddn'] = 'LDAP Bind DN';
$_gmsg['l_ldapbindpasswd'] = 'LDAP Bind Password';
$_gmsg['l_ldaprealmdef'] = 'LDAP Realm Definition';
$_gmsg['l_listenerlist'] = 'Listener List';
$_gmsg['l_listenername'] = 'Listener Name';
$_gmsg['l_loadapacheconf'] = 'Load Apache Configuration';
$_gmsg['l_loadbalancer'] = 'Load Balancer';
$_gmsg['l_location'] = 'Location';
$_gmsg['l_logcontrol'] = 'Log Control';
$_gmsg['l_logformat'] = 'Log Format';
$_gmsg['l_loggeraddress'] = 'Address for remote logger (Optional)';
$_gmsg['l_logheaders'] = 'Log Headers';
$_gmsg['l_loglevel'] = 'Log Level';
$_gmsg['l_lsapiapp'] = 'LSAPI App';
$_gmsg['l_lsrecaptcha'] = 'LS reCAPTCHA';
$_gmsg['l_mappedlisteners'] = 'Mapped Listeners';
$_gmsg['l_matchedhosts'] = 'REGEX Matched Domains';
$_gmsg['l_maxCGIInstances'] = 'Max CGI Instances';
$_gmsg['l_maxTries'] = 'Max Tries';
$_gmsg['l_maxcachedfilesize'] = 'Max Cached Small File Size (bytes)';
$_gmsg['l_maxconns'] = 'Max Connections';
$_gmsg['l_maxdynrespheadersize'] = 'Max Dynamic Response Header Size (bytes)';
$_gmsg['l_maxdynrespsize'] = 'Max Dynamic Response Body Size (bytes)';
$_gmsg['l_maxidletime'] = 'Max Idle Time';
$_gmsg['l_maxkeepalivereq'] = 'Max Keep-Alive Requests';
$_gmsg['l_maxmmapfilesize'] = 'Max MMAP File Size (bytes)';
$_gmsg['l_maxobjsize'] = 'Max Object Size';
$_gmsg['l_maxreqbodysize'] = 'Max Request Body Size (bytes)';
$_gmsg['l_maxreqheadersize'] = 'Max Request Header Size (bytes)';
$_gmsg['l_maxrequrllen'] = 'Max Request URL Length (bytes)';
$_gmsg['l_maxsslconns'] = 'Max SSL Connections';
$_gmsg['l_membervhosts'] = 'Member Virtual Hosts';
$_gmsg['l_membervhroot'] = 'Member Virtual Host Root';
$_gmsg['l_membervhroot_note'] = 'Optional: You can set up a different VH_ROOT other than the default one';
$_gmsg['l_memhardlimit'] = 'Memory Hard Limit (bytes)';
$_gmsg['l_memsoftlimit'] = 'Memory Soft Limit (bytes)';
$_gmsg['l_mimesettings'] = 'MIME Settings';
$_gmsg['l_mimetype'] = 'MIME Type';
$_gmsg['l_mimetypedef'] = 'MIME Type Definition';
$_gmsg['l_mimetypeentry'] = 'MIME Type Entry';
$_gmsg['l_mingid'] = 'Minimum GID';
$_gmsg['l_minuid'] = 'Minimum UID';
$_gmsg['l_module'] = 'Module';
$_gmsg['l_moduleconf'] = 'Module Configuration';
$_gmsg['l_modulehandler'] = 'Module Handler';
$_gmsg['l_moduleparams'] = 'Module Parameters';
$_gmsg['l_name'] = 'Name';
$_gmsg['l_newadminuser'] = 'New WebAdmin Console User';
$_gmsg['l_newcontext'] = 'New Context';
$_gmsg['l_newextapp'] = 'New External App';
$_gmsg['l_newpass'] = 'New Password';
$_gmsg['l_newrealm'] = 'New Realm';
$_gmsg['l_nocachedomain'] = 'Do-Not-Cache Domains';
$_gmsg['l_nocacheurl'] = 'Do-Not-Cache URL';
$_gmsg['l_nodebin'] = 'Node Path';
$_gmsg['l_nodesettings'] = 'Node.js App Default Settings';
$_gmsg['l_notes'] = 'Notes';
$_gmsg['l_numworkers'] = 'Number of Workers';
$_gmsg['l_ocspcacerts'] = 'OCSP CA Certificates';
$_gmsg['l_ocsprespmaxage'] = 'OCSP Response Max Age (secs)';
$_gmsg['l_ocspresponder'] = 'OCSP Responder';
$_gmsg['l_ocspstapling'] = 'OCSP Stapling';
$_gmsg['l_oldpass'] = 'Old Password';
$_gmsg['l_onlyself'] = 'Only Self Reference';
$_gmsg['l_order'] = 'Order';
$_gmsg['l_outbandwidth'] = 'Outbound Bandwidth (bytes/sec)';
$_gmsg['l_pass'] = 'Password';
$_gmsg['l_passfilerealmdef'] = 'Password File Realm Definition';
$_gmsg['l_path'] = 'Path';
$_gmsg['l_pckeepalivetimeout'] = 'Connection Keep-Alive Timeout';
$_gmsg['l_perclientthrottle'] = 'Per Client Throttling';
$_gmsg['l_persistconn'] = 'Persistent Connection';
$_gmsg['l_phpinioverride'] = 'php.ini Override';
$_gmsg['l_phpsuexec'] = 'PHP suEXEC';
$_gmsg['l_phpsuexecmaxconn'] = 'PHP suEXEC Max Conn';
$_gmsg['l_pipedlogger'] = 'Piped Logger';
$_gmsg['l_port'] = 'Port';
$_gmsg['l_priority'] = 'Priority';
$_gmsg['l_privatecacheexpiretime'] = 'Private Cache Expire Time (seconds)';
$_gmsg['l_process'] = 'Process';
$_gmsg['l_prochardlimit'] = 'Process Hard Limit';
$_gmsg['l_procsoftlimit'] = 'Process Soft Limit';
$_gmsg['l_protocolver'] = 'Protocol Version';
$_gmsg['l_quic'] = 'QUIC';
$_gmsg['l_quicbaseplpmtu'] = 'PLPMTU Base Value';
$_gmsg['l_quiccfcw'] = 'Connection Flow Control Window';
$_gmsg['l_quicenabledplpmtud'] = 'Enable DPLPMTUD';
$_gmsg['l_quichandshaketimeout'] = 'Handshake Timeout (secs)';
$_gmsg['l_quicidletimeout'] = 'Idle Timeout (secs)';
$_gmsg['l_quicmaxcfcw'] = 'Max Connection Flow Control Window';
$_gmsg['l_quicmaxplpmtu'] = 'PLPMTU Max Value';
$_gmsg['l_quicmaxsfcw'] = 'Max Stream Flow Control Window';
$_gmsg['l_quicmaxstreams'] = 'Max Concurrent Streams Per Connection';
$_gmsg['l_quicsfcw'] = 'Stream Flow Control Window';
$_gmsg['l_quicshmdir'] = 'QUIC SHM Directory';
$_gmsg['l_quicversions'] = 'QUIC Versions';
$_gmsg['l_railsapplimit'] = 'Max Apps per Account';
$_gmsg['l_railshosting'] = 'Rack/Rails Shared Hosting';
$_gmsg['l_railssettings'] = 'Rack/Rails Default Settings';
$_gmsg['l_ramdiskpath'] = 'RAM Disk Path';
$_gmsg['l_rcvbufsize'] = 'Receive Buffer Size (bytes)';
$_gmsg['l_realm'] = 'Realm';
$_gmsg['l_realmlist'] = 'Realm List';
$_gmsg['l_realmname'] = 'Realm Name';
$_gmsg['l_realmtype'] = 'DB Type';
$_gmsg['l_recapenabled'] = 'Enable reCAPTCHA';
$_gmsg['l_recaptype'] = 'reCAPTCHA Type';
$_gmsg['l_redirecturi'] = 'Redirect URL';
$_gmsg['l_regConnLimit'] = 'Connection Limit';
$_gmsg['l_renegprotection'] = 'SSL Renegotiation Protection';
$_gmsg['l_reqresp'] = 'Request/Response';
$_gmsg['l_requestfilterruleset'] = 'Request Filtering Rule Set';
$_gmsg['l_requiredauthuser'] = 'Require (Authorized Users/Groups)';
$_gmsg['l_requiredpermissionmask'] = 'Required Permission Mask';
$_gmsg['l_respbuffer'] = 'Response Buffering';
$_gmsg['l_restrained'] = 'Restrained';
$_gmsg['l_restricteddirpermissionmask'] = 'Script Restricted Directory Permission Mask';
$_gmsg['l_restrictedpermissionmask'] = 'Restricted Permission Mask';
$_gmsg['l_restrictedscriptpermissionmask'] = 'Script Restricted Permission Mask';
$_gmsg['l_retrytimeout'] = 'Retry Timeout (secs)';
$_gmsg['l_retypepass'] = 'Retype Password';
$_gmsg['l_reuseport'] = 'Enable REUSEPORT';
$_gmsg['l_rewritebase'] = 'Rewrite Base';
$_gmsg['l_rewritecontrol'] = 'Rewrite Control';
$_gmsg['l_rewritedocrootrules'] = 'Document Root Rewrite Rules';
$_gmsg['l_rewriteinherit'] = 'Rewrite Inherit';
$_gmsg['l_rewritemap'] = 'Rewrite Map';
$_gmsg['l_rewriterules'] = 'Rewrite Rules';
$_gmsg['l_rollingsize'] = 'Rolling Size (bytes)';
$_gmsg['l_rubybin'] = 'Ruby Path';
$_gmsg['l_rubyproclimit'] = 'Max Ruby Processes per Account';
$_gmsg['l_ruleset'] = 'Rules Definition';
$_gmsg['l_runningas'] = 'Running As';
$_gmsg['l_runonstartup'] = 'Run On Start Up';
$_gmsg['l_runtimemode'] = 'Run-time Mode';
$_gmsg['l_scanpost'] = 'Scan Request Body';
$_gmsg['l_secauditlog'] = 'Security Audit Log';
$_gmsg['l_secauditlogengine'] = 'Enable Security Audit Log';
$_gmsg['l_secretKey'] = 'Secret Key';
$_gmsg['l_secure'] = 'Secure';
$_gmsg['l_securedconn'] = 'Secured Connection';
$_gmsg['l_securityandfeatures'] = 'Security & Features';
$_gmsg['l_serverlog'] = 'Server Log';
$_gmsg['l_servermoduledef'] = 'Server Module Definition';
$_gmsg['l_servermodulesdef'] = 'Server Modules Definition';
$_gmsg['l_servername'] = 'Server Name';
$_gmsg['l_serverprocess'] = 'Server Process';
$_gmsg['l_serversig'] = 'Server Signature';
$_gmsg['l_servletengine'] = 'Servlet Engine';
$_gmsg['l_sessiontimeout'] = 'Session Timeout (secs)';
$_gmsg['l_setuidmode'] = 'External App Set UID Mode';
$_gmsg['l_shdef'] = 'Script Handler Definition';
$_gmsg['l_shmDefaultDir'] = 'Default SHM Directory';
$_gmsg['l_sitealiases'] = 'Site Aliases';
$_gmsg['l_sitedomain'] = 'Site Domain';
$_gmsg['l_sitekey'] = 'Site Key';
$_gmsg['l_smartkeepalive'] = 'Smart Keep-Alive';
$_gmsg['l_sndbufsize'] = 'Send Buffer Size (bytes)';
$_gmsg['l_softlimit'] = 'Connection Soft Limit';
$_gmsg['l_ssl'] = 'SSL Private Key & Certificate';
$_gmsg['l_sslConnLimit'] = 'SSL Connection Limit';
$_gmsg['l_sslEnableMultiCerts'] = 'Enable Multiple SSL Certificates';
$_gmsg['l_sslSessionCache'] = 'Enable Session Cache';
$_gmsg['l_sslSessionCacheSize'] = 'Session Cache Size (bytes)';
$_gmsg['l_sslSessionCacheTimeout'] = 'Session Cache Timeout (secs)';
$_gmsg['l_sslSessionTicketKeyFile'] = 'SSL Session Ticket Key File';
$_gmsg['l_sslSessionTicketLifetime'] = 'SSL Session Ticket Lifetime (secs)';
$_gmsg['l_sslSessionTickets'] = 'Enable Session Tickets';
$_gmsg['l_sslStrongDhKey'] = 'SSL Strong DH Key';
$_gmsg['l_sslprotocol'] = 'SSL Protocol';
$_gmsg['l_startupfile'] = 'Startup File';
$_gmsg['l_statDir'] = 'Statistics Output Directory';
$_gmsg['l_staticreqpersec'] = 'Static Requests/second';
$_gmsg['l_statuscode'] = 'Status Code';
$_gmsg['l_storagepath'] = 'Storage Path';
$_gmsg['l_suexecgrp'] = 'Run As Group';
$_gmsg['l_suexecgrp1'] = 'suEXEC Group';
$_gmsg['l_suexecuser'] = 'Run As User';
$_gmsg['l_suexecuser1'] = 'suEXEC User';
$_gmsg['l_suffix'] = 'Suffixes';
$_gmsg['l_suspendvh'] = 'Suspend Vhosts';
$_gmsg['l_swappingdir'] = 'Swapping Directory';
$_gmsg['l_templatefile'] = 'Template File';
$_gmsg['l_totalinmemcachesize'] = 'Total Small File Cache Size (bytes)';
$_gmsg['l_totalmmapcachesize'] = 'Total MMAP Cache Size (bytes)';
$_gmsg['l_tplist'] = 'Virtual Host Template List';
$_gmsg['l_tpname'] = 'Template Name';
$_gmsg['l_tuningos'] = 'OS Optimization';
$_gmsg['l_tuningsslsettings'] = 'SSL Global Settings';
$_gmsg['l_tuningstatic'] = 'Static File Delivery Optimization';
$_gmsg['l_type'] = 'Type';
$_gmsg['l_umask'] = 'umask';
$_gmsg['l_updateinterval'] = 'Update Interval';
$_gmsg['l_updatemode'] = 'Update Mode';
$_gmsg['l_updateoffsetsecs'] = 'Update Offset (secs)';
$_gmsg['l_uploadfile'] = 'File Upload';
$_gmsg['l_uploadpassbypath'] = 'Pass Upload Data by File Path';
$_gmsg['l_uploadtmpdir'] = 'Temporary File Path';
$_gmsg['l_uploadtmpfilepermission'] = 'Temporary File Permission';
$_gmsg['l_uri'] = 'URI';
$_gmsg['l_url'] = 'URL';
$_gmsg['l_urlfilter'] = 'Context';
$_gmsg['l_useServer'] = 'Use Server\'s Log';
$_gmsg['l_useaio'] = 'Use Asynchronized disk I/O (AIO)';
$_gmsg['l_useapacheconf'] = 'Using Apache Configuration File';
$_gmsg['l_useipinproxyheader'] = 'Use Client IP in Header';
$_gmsg['l_userdbattrmemberof'] = 'Member-of Attribute';
$_gmsg['l_userdbattrpasswd'] = 'Password Attribute';
$_gmsg['l_userdbcachetimeout'] = 'User DB Cache Timeout (secs)';
$_gmsg['l_userdbentries'] = 'User DB Entries';
$_gmsg['l_userdbentry'] = 'User DB Entry';
$_gmsg['l_userdblocation'] = 'User DB Location';
$_gmsg['l_userdbmaxcachesize'] = 'User DB Max Cache Size';
$_gmsg['l_username'] = 'User Name';
$_gmsg['l_users'] = 'Users';
$_gmsg['l_usesendfile'] = 'Use sendfile()';
$_gmsg['l_useserverindexfiles'] = 'Use Server Index Files';
$_gmsg['l_verifydepth'] = 'Verify Depth';
$_gmsg['l_vhaliases'] = 'Domain Aliases';
$_gmsg['l_vhlog'] = 'Virtual Host Log';
$_gmsg['l_vhmappings'] = 'Virtual Host Mappings';
$_gmsg['l_vhname'] = 'Virtual Host Name';
$_gmsg['l_vhost'] = 'Virtual Host';
$_gmsg['l_vhostlist'] = 'Virtual Host List';
$_gmsg['l_vhroot'] = 'Virtual Host Root';
$_gmsg['l_vhtemplate'] = 'Virtual Host Template';
$_gmsg['l_webserver'] = 'Web Server';
$_gmsg['l_websocketdef'] = 'Web Socket Definition';
$_gmsg['l_websocketsetup'] = 'Web Socket Proxy Setup';
$_gmsg['l_workers'] = 'Workers';
$_gmsg['l_workingdir'] = 'Working Directory';
$_gmsg['l_wsgibin'] = 'WSGI Path';
$_gmsg['l_wsgisettings'] = 'Python WSGI Default Settings';


$_gmsg['o_cagefswithoutsuexec'] = 'CageFS without suEXEC';
$_gmsg['o_checkbox'] = 'Checkbox';
$_gmsg['o_custchrootpath'] = 'Customized Chroot Path';
$_gmsg['o_daily'] = 'Daily';
$_gmsg['o_deprecated'] = 'deprecated';
$_gmsg['o_disabled'] = 'Disabled';
$_gmsg['o_enableabortforallreq'] = 'Enable Abort for All Requests';
$_gmsg['o_enableabortforreqfromexternalip'] = 'Enable Abort for Requests from External IPs';
$_gmsg['o_hidefullheader'] = 'Hide Full Header';
$_gmsg['o_hidever'] = 'Hide Version';
$_gmsg['o_high'] = 'High';
$_gmsg['o_hourly'] = 'Hourly';
$_gmsg['o_ifownermatch'] = 'If Owner Match';
$_gmsg['o_invisible'] = 'Invisible';
$_gmsg['o_keepfilemapped'] = 'Keep File Mapped (64 bit OS)';
$_gmsg['o_keepheaderfortrusted'] = 'Keep Header from Trusted IP';
$_gmsg['o_low'] = 'Low';
$_gmsg['o_medium'] = 'Medium';
$_gmsg['o_modifiedtime'] = 'Modified Time';
$_gmsg['o_monthly'] = 'Monthly';
$_gmsg['o_no'] = 'No';
$_gmsg['o_noabort'] = 'No Abort';
$_gmsg['o_nofornph'] = 'No for Non-Parsed-Header (NPH)';
$_gmsg['o_none'] = 'None';
$_gmsg['o_notset'] = 'Not Set';
$_gmsg['o_off'] = 'Off';
$_gmsg['o_on'] = 'On';
$_gmsg['o_overridecpanelrestartscript'] = 'Override cPanel restart HTTPD script';
$_gmsg['o_ownlogfile'] = 'Own Log File';
$_gmsg['o_sameasserver'] = 'Same as Server';
$_gmsg['o_serverslogfile'] = 'Server\'s Log File';
$_gmsg['o_showver'] = 'Show Version';
$_gmsg['o_size'] = 'Size';
$_gmsg['o_thrucgidaemon'] = 'Yes (Through CGI Daemon)';
$_gmsg['o_trustediponly'] = 'Trusted IP Only';
$_gmsg['o_use_last_ip_for elb'] = 'Use Last IP (for AWS ELB)';
$_gmsg['o_useapachebinwrapper'] = 'Use Apache binary wrapper';
$_gmsg['o_userhomedironly'] = 'User\'s Home Directory Only';
$_gmsg['o_vhroot'] = 'Virtual Host Root';
$_gmsg['o_weekly'] = 'Weekly';
$_gmsg['o_yes'] = 'Yes';
$_gmsg['o_yesdaemonmode'] = 'Yes (Daemon Mode)';
$_gmsg['o_yesdetachmode'] = 'Yes (Detached Mode)';


$_gmsg['parse_awstatsuri'] = 'starts with / and ends with /';
$_gmsg['parse_compressibletypes'] = '(!)MIME types, like */*, text/*, text/html, text/*, !text/css';
$_gmsg['parse_defaultmimetype'] = 'MIME_type like text/html';
$_gmsg['parse_env'] = 'PROPERTY=VALUE';
$_gmsg['parse_expiresByType'] = 'MIME_type=A|Mseconds, MIME type can be like */*, text/*, text/html';
$_gmsg['parse_expiresdefault'] = '[A|M]###, A means client access time, M means file modified time, ### is number of seconds';
$_gmsg['parse_forcemimetype'] = 'MIME_type like text/html, or put "NONE" to disable inherited Force Type.';
$_gmsg['parse_geodbenv'] = 'Variable_Name mapped_DB_data';
$_gmsg['parse_mimetype'] = 'like text/html';
$_gmsg['parse_recaptchakey'] = 'key string assigned from your google reCAPTCHA account';
$_gmsg['parse_rewritemaplocation'] = 'txt:/location or rnd:/location or int:(toupper|tolower|escape|unescape)';
$_gmsg['parse_secpermissionmask'] = '3 digits or more octet number. Default is 000';
$_gmsg['parse_spdyadheader'] = 'required format: ssl_port:npn-spdy/version like 443:npn-spdy/3';
$_gmsg['parse_suffix'] = 'comma-separated list, allowed character[A-z0-9_\\-]';
$_gmsg['parse_tpfile'] = 'requiring variable $VH_NAME or $VH_ROOT';
$_gmsg['parse_tpname'] = 'requiring variable $VH_NAME';
$_gmsg['parse_tpvhconffile'] = 'Requiring variable $VH_NAME and end with .conf. Suggested location is $SERVER_ROOT/conf/vhosts/$VH_NAME/vhconf.conf';
$_gmsg['parse_umask'] = '[000-777]';
$_gmsg['parse_uploadtmpfilepermission'] = '3 digits octet number, Default value is 666';
$_gmsg['parse_userdblocation'] = 'start with ldap:// or ldaps://';


$_gmsg['service_active'] = 'Active';
$_gmsg['service_addtomonitor'] = 'Add to monitoring';
$_gmsg['service_at'] = 'at';
$_gmsg['service_availconn'] = 'Free Conn';
$_gmsg['service_availssl'] = 'Free SSL Conn';
$_gmsg['service_blockedipcnt'] = 'Anti-DDoS Blocked IP Count';
$_gmsg['service_bpsin'] = 'Http In (KB)';
$_gmsg['service_bpsout'] = 'Http Out (KB)';
$_gmsg['service_confirmmonitor'] = 'Are you sure you want to monitor';
$_gmsg['service_debuglogstatus'] = 'Debug Log';
$_gmsg['service_disabled'] = 'Disabled';
$_gmsg['service_displevel'] = 'Display Level';
$_gmsg['service_eapcount'] = 'ExtApp Count';
$_gmsg['service_eapidle'] = 'EAProc Idle';
$_gmsg['service_eapinuse'] = 'EAProc In Use';
$_gmsg['service_eapreqpersec'] = 'EAProc Req/Sec';
$_gmsg['service_eapwaitq'] = 'EAProc WaitQ';
$_gmsg['service_effmax'] = 'Eff Max';
$_gmsg['service_enablevh'] = 'Enable this VHost';
$_gmsg['service_enterpass'] = 'Enter your password';
$_gmsg['service_enteruser'] = 'Please enter user name';
$_gmsg['service_error'] = 'Error';
$_gmsg['service_filterbyvn'] = 'Filter by VH Name';
$_gmsg['service_gotologviewer'] = 'Go to Log Viewer';
$_gmsg['service_higheston'] = 'Highest happened on';
$_gmsg['service_idle'] = 'Idle';
$_gmsg['service_idleconn'] = 'Http Idle';
$_gmsg['service_intemplate'] = 'In Template';
$_gmsg['service_inuse'] = 'In Use';
$_gmsg['service_ismonitored'] = 'is already monitored';
$_gmsg['service_length'] = 'Length';
$_gmsg['service_level'] = 'Level';
$_gmsg['service_livefeeds'] = 'Live Feeds';
$_gmsg['service_loglastsize'] = 'Last %%size%%';
$_gmsg['service_logresnote'] = 'Searched %%totallines%% log entries and found %%outlines%% above level %%level%%';
$_gmsg['service_maxconn'] = 'Max Conn';
$_gmsg['service_maxsslconn'] = 'Max SSL Conn';
$_gmsg['service_mesg'] = 'Message';
$_gmsg['service_minutes'] = 'Minutes';
$_gmsg['service_monitormaxallowed'] = 'You can only monitor up to';
$_gmsg['service_nameallowexp'] = 'name allows regExp';
$_gmsg['service_notrunning'] = 'Not running';
$_gmsg['service_plainconn'] = 'Http Used';
$_gmsg['service_pool'] = 'Pool';
$_gmsg['service_realtime'] = 'Realtime';
$_gmsg['service_refreshinterval'] = 'Refresh Interval';
$_gmsg['service_reqpersec'] = 'Requests/Sec';
$_gmsg['service_reqprocessing'] = 'Requests in Processing';
$_gmsg['service_requesting'] = 'Requesting';
$_gmsg['service_restartconfirm'] = 'Are you sure you want to restart LiteSpeed?';
$_gmsg['service_resumevhconfirm'] = 'Are you sure you want to resume this virtual host?';
$_gmsg['service_retrieve'] = 'Retrieve';
$_gmsg['service_running'] = 'Running';
$_gmsg['service_scope'] = 'Scope';
$_gmsg['service_searchfrom'] = 'Search From';
$_gmsg['service_seconds'] = 'Seconds';
$_gmsg['service_server'] = 'Server';
$_gmsg['service_servererrlog'] = 'Server Error Log';
$_gmsg['service_size'] = 'Size';
$_gmsg['service_sslbpsin'] = 'Https In (KB)';
$_gmsg['service_sslbpsout'] = 'Https Out (KB)';
$_gmsg['service_sslconn'] = 'Https Used';
$_gmsg['service_stop'] = 'Stop';
$_gmsg['service_stopped'] = 'Stopped';
$_gmsg['service_suspendvh'] = 'Suspend this VHost';
$_gmsg['service_suspendvhconfirm'] = 'Are you sure you want to suspend this virtual host?';
$_gmsg['service_time'] = 'Time';
$_gmsg['service_toggledebug'] = 'Are you sure you want to toggle debug logging?';
$_gmsg['service_toggledebuglog'] = 'Toggle Debug Logging';
$_gmsg['service_toggledebugmsg'] = 'With debug logging turned on, you may fill up disk space. Only turn on for debug purpose and for short period of time.';
$_gmsg['service_totalreq'] = 'Total Requests';
$_gmsg['service_uptime'] = 'LSWS Uptime';
$_gmsg['service_waitq'] = 'WaitQ';
$_gmsg['service_was'] = 'was';
$_gmsg['service_willrefresh'] = 'Current page will be refreshed after a few seconds...';


$_gmsg['buildphp_addonmodules'] = 'Add-on Modules';
$_gmsg['buildphp_binarylocnote'] = 'If the build process is successful, the PHP binary will be created under %%server_root%%fcgi-bin/ with
		name %%binname%%, and a symbolic link of lsphp%%phpver%% will be created or updated to the newly built binary.
		If %%binname%% already exists, it will be renamed to %%binname%%.bak.';
$_gmsg['buildphp_compilerflags'] = 'Compiler Flags';
$_gmsg['buildphp_confparam'] = 'Configure Parameters';
$_gmsg['buildphp_confsaved'] = 'Configuration saved successfully. you can retrieve it for next build.';
$_gmsg['buildphp_detaillog'] = 'Detailed Log';
$_gmsg['buildphp_eaccelerator'] = '(Opcode Cache) Only support PHP 5.2 ~ 5.4';
$_gmsg['buildphp_enableextnote'] = 'To enable the extension, please make sure the following is added to
				 your php.ini configuration file. In addition, you may need to check the log detail to
				 determine the directory where your extensions are installed and add the directory to the
				 extensions path in your php.ini configuration file.';
$_gmsg['buildphp_errchmod'] = 'Failed to chmod for';
$_gmsg['buildphp_errcreatescript'] = 'Failed to create script';
$_gmsg['buildphp_errinprogress'] = 'Current batch is in progress.';
$_gmsg['buildphp_errnobash'] = 'This build tool requires bash to be installed (command: pkg_add -r bash). Please make sure bash is available before going to next step.';
$_gmsg['buildphp_errquotes'] = 'Please use single quote to replace double-quotes';
$_gmsg['buildphp_extrapathenv'] = 'Extra PATH environment';
$_gmsg['buildphp_failgenscript'] = 'Fail to generate build script, please try to manually fix the error first.';
$_gmsg['buildphp_failsaveconf'] = 'Fail to save current configuration.';
$_gmsg['buildphp_finishsuccess'] = 'Finished successfully.';
$_gmsg['buildphp_installpathprefix'] = 'Installation Path Prefix';
$_gmsg['buildphp_loadconf'] = 'Load Configuration';
$_gmsg['buildphp_mailheader1'] = 'PHP Mail Header Patch';
$_gmsg['buildphp_mailheader2'] = 'Identifies Mail Source';
$_gmsg['buildphp_mainstatus'] = 'Main Status';
$_gmsg['buildphp_manualrunnotice'] = '<p>For security reasons, please log in to your server and run the pre-generated script from shell.
	You can monitor the progress from this screen.</p>
	<p>If build successfully, please update php.ini accordingly if needed. To apply changes, please do a graceful restart.</p>
	<p>If it stops due to errors, it may caused by missing packages, after you install it, rerun the same command and this page will show the updated log. For more information regarding LSPHP, please visit <a href="https://www.litespeedtech.com/support/wiki/doku.php/litespeed_wiki:php" rel="noopener noreferrer" target="_blank">LiteSpeed wiki</a>.</p>
	<p>If you log in as root, you can directly run the command: <br><code>%%manual_script%%</code></p>
	<p>If you log in as a user who has sudo permission, you can run the command with sudo and input root password after prompt.
	<code>sudo %%manual_script%%</code></p>';
$_gmsg['buildphp_nobrowserrefresh'] = 'Please do not use the browser refresh, back and forward buttons while building PHP.';
$_gmsg['buildphp_opcodecache'] = 'Opcode Cache';
$_gmsg['buildphp_phpver'] = 'PHP Version';
$_gmsg['buildphp_restoredefault'] = 'Restore Defaults';
$_gmsg['buildphp_step1'] = 'Select PHP Version';
$_gmsg['buildphp_step2'] = 'Choose Build Options';
$_gmsg['buildphp_step3'] = 'Download Source Code';
$_gmsg['buildphp_step4'] = 'Compile and Monitor';
$_gmsg['buildphp_stopduetoerr'] = 'Stopped due to Error. Please check the log and manually fix it.';
$_gmsg['buildphp_suhosin'] = '(General Hardening) only support PHP 5.4 and 5.5';
$_gmsg['buildphp_updatever'] = 'If you want to use a version not listed here, you can manually update the settings in ';
$_gmsg['buildphp_useprevconf'] = 'Use Configuration from Previous Build';


$_gmsg['mail_failedlogin'] = 'LiteSpeed Web Admin Console Failed Login Attempt';
$_gmsg['mail_failedlogin_c'] = 'A recent login attempt to LiteSpeed web admin console failed. Details of the attempt are below.

	Date/Time: %%date%%
	Username: %%authUser%%
	IP Address: %%ip%%
	URL: %%url%%

If you do not recognize the IP address, please follow below recommended ways to secure your admin console:

1. set access allowed list to limit certain IPs that can access under WebAdmin WebConsole->General->AccessControl;
2. change the listener port from default value 7080;
3. do not use simple password;
4. use https for admin console.';
